%define compactversion		2018

%global __requires_exclude	Win32

%define graphic_format		png	# use "gif" or "png"
%define latex2htmldir		%{_prefix}/lib/%{name}

Name:		latex2html
Summary:	LaTeX to HTML converter
Version:	2020.2
Release:	%mkrel 1
License:	GPLv2+
Group:		Publishing
URL:		https://www.latex2html.org
Source:		https://github.com/latex2html/latex2html/archive/v%{version}/%{name}-%{version}.tar.gz
Patch1:		%{name}-%{compactversion}-path.patch
Patch2:		%{name}-perlcall.patch
Patch3:		%{name}-htmladdimg.patch
BuildArch:	noarch
BuildRequires:	dvips
BuildRequires:	texlive-texmf
BuildRequires:	dvipdf
BuildRequires:	ghostscript

Requires:	ghostscript >= 6.50
Requires:	giftrans
Requires:	netpbm
Requires:	latex
Requires:	dvips

%description
Elaborate perl program to convert latex documents to html, using LaTeX
to process images and equations.

%prep
%setup -q
%autopatch -p1


%build
TMP=/var/tmp ./configure \
	--with-gs=%{_bindir}/gs \
	--with-texpath=%{_datadir}/texmf/tex/ \
	--without-mktexlsr \
	--with-perl=%{__perl} \
	--prefix=%{_prefix} \
	--shlibdir=%{latex2htmldir} \
	--with-initex="%{_bindir}/tex -ini" \
	--with-rgb=%{_datadir}/X11/rgb.txt
%make_build

%install
# custom "make install" so paths are proper in the perl programs

mkdir -p %{buildroot}%{_bindir} \
	%{buildroot}%{latex2htmldir}

install -m 755 latex2html %{buildroot}%{_bindir}
install -m 755 pstoimg %{buildroot}%{_bindir}
install -m 755 texexpand %{buildroot}%{_bindir}

cp -avRf IndicTeX-HTML %{buildroot}%{latex2htmldir}/
cp -avRf L2hos.pm %{buildroot}%{latex2htmldir}/
cp -avRf L2hos %{buildroot}%{latex2htmldir}/
cp -avRf XyMTeX-HTML %{buildroot}%{latex2htmldir}/
cp -avRf cweb2html %{buildroot}%{latex2htmldir}/
cp -avRf docs %{buildroot}%{latex2htmldir}/
cp -avRf example %{buildroot}%{latex2htmldir}/
cp -avRf foilhtml %{buildroot}%{latex2htmldir}/
cp -avRf icons %{buildroot}%{latex2htmldir}/
cp -avRf makeseg %{buildroot}%{latex2htmldir}/
cp -avRf styles %{buildroot}%{latex2htmldir}/
cp -avRf texinputs %{buildroot}%{latex2htmldir}/
cp -avRf versions %{buildroot}%{latex2htmldir}/

cp -avRf cfgcache.pm dot.latex2html-init l2hconf.pm makemap docs/hthtml/readme.hthtml \
	%{buildroot}%{latex2htmldir}/

mkdir -p %{buildroot}%{_datadir}/texmf/tex/latex/html
cp -avRf texinputs/* %{buildroot}%{_datadir}/texmf/tex/latex/html

mkdir -p %{buildroot}%{_defaultdocdir}/%{name}-%{version}
cp -avRf Changes FAQ MANIFEST README.md TODO BUGS \
	dot.latex2html-init example docs/hthtml/readme.hthtml \
		%{buildroot}%{_defaultdocdir}/%{name}-%{version}

# fix perl path in a few places:
perl -pi -e 's#/usr/local/bin/perl#%{__perl}#' %{buildroot}%{_prefix}/lib/latex2html/cweb2html/cweb2html
perl -pi -e 's#/usr/local/bin/perl#%{__perl}#' %{buildroot}%{_prefix}/lib/latex2html/makeseg/makeseg
perl -pi -e 's#/usr/local/bin/perl#%{__perl}#' %{buildroot}%{latex2htmldir}/makemap

# fix some installation path
perl -pi -e "s#$RPM_BUILD_DIR/%{name}-%{compactversion}#%{latex2htmldir}#" \
	%{buildroot}%{latex2htmldir}/cfgcache.pm
perl -pi -e "s#%{_datadir}/lib/latex2html#%{latex2htmldir}#" \
	%{buildroot}%{latex2htmldir}/cfgcache.pm

# these files are already included in tetex
(cd %{buildroot}%{_datadir}/texmf/tex/latex/html
rm -f floatflt.ins latin9.def url.sty
)

(cd docs
rm -f changebar.sty url.sty
TEXINPUTS=.:../texinputs:
export TEXINPUTS
latex manual
latex manual
latex manual
dvipdf manual.dvi
install -m 644 manual.pdf %{buildroot}%{_defaultdocdir}/%{name}-%{version})

%post
[ -x /usr/bin/texhash ] && /usr/bin/env - /usr/bin/texhash 2> /dev/null
exit 0

%postun
[ -x /usr/bin/texhash ] && /usr/bin/env - /usr/bin/texhash 2> /dev/null
exit 0

%files
%{_bindir}/*
%dir %{latex2htmldir}
%{latex2htmldir}/*
%{_datadir}/texmf/tex/latex/html/
%{_docdir}/%{name}-%{version}


%changelog
* Tue Jul 14 2020 daviddavid <daviddavid> 2020.2-1.mga8
+ Revision: 1606145
- new version: 2020.2

* Thu Feb 20 2020 umeabot <umeabot> 2020-2.mga8
+ Revision: 1546129
- Mageia 8 Mass Rebuild

* Fri Jan 31 2020 daviddavid <daviddavid> 2020-1.mga8
+ Revision: 1486112
- new version: 2020

* Fri Aug 30 2019 daviddavid <daviddavid> 2019.2-1.mga8
+ Revision: 1435306
- new version: 2019.2

* Sat Apr 13 2019 daviddavid <daviddavid> 2019-1.mga7
+ Revision: 1389671
- new version: 2019

* Thu Sep 20 2018 umeabot <umeabot> 2018.3-2.mga7
+ Revision: 1279193
- Mageia 7 Mass Rebuild

* Tue Aug 14 2018 daviddavid <daviddavid> 2018.3-1.mga7
+ Revision: 1251441
- new version: 2018.3

* Mon Jun 25 2018 daviddavid <daviddavid> 2018.2-1.mga7
+ Revision: 1239689
- new version: 2018.2

* Wed Feb 14 2018 daviddavid <daviddavid> 2018-1.mga7
+ Revision: 1200968
- new version: 2018
- rename and rediff 2002-2-1-path patch

* Mon Feb 06 2017 daviddavid <daviddavid> 2017.2-1.mga6
+ Revision: 1085013
- new version: 2017.2
- remove merged upstream patches

* Fri Feb 05 2016 umeabot <umeabot> 2012-5.mga6
+ Revision: 937460
- Mageia 6 Mass Rebuild

* Fri Feb 05 2016 umeabot <umeabot> 2012-4.mga6
+ Revision: 937013
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 2012-3.mga5
+ Revision: 746684
- Second Mageia 5 Mass Rebuild
- Mageia 5 Mass Rebuild
+ tv <tv>
- use %%global for req/prov exclude
- autoconvert to new prov/req excludes

* Sat Sep 06 2014 spuhler <spuhler> 2012-1.mga5
+ Revision: 672847
- upgrade to 2012
- removed match-multiline patch
- removed source included patch, latex2html-fix-defined.patch

* Tue Oct 22 2013 umeabot <umeabot> 2008-9.mga4
+ Revision: 545911
- Mageia 4 Mass Rebuild

* Thu Oct 17 2013 luigiwalser <luigiwalser> 2008-8.mga4
+ Revision: 501974
- BR texlive-texmf

* Mon Mar 04 2013 boklm <boklm> 2008-7.mga3
+ Revision: 401401
- Add eurosym.patch from debian: adding support for eurosymbol package
- Add latex2html-fix-defined.patch from debian: removing a perl warning

* Mon Mar 04 2013 boklm <boklm> 2008-6.mga3
+ Revision: 401397
- add match-multiline.patch from debian, fixing incompatibility with perl >= 5.10

* Sat Jan 12 2013 umeabot <umeabot> 2008-5.mga3
+ Revision: 356648
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Mar 04 2011 boklm <boklm> 2008-4.mga1
+ Revision: 64167
- require latex and dvips instead of tetex-latex and tetex-dvips

* Thu Jan 13 2011 ahmad <ahmad> 2008-3.mga1
+ Revision: 8871
- imported package latex2html


* Mon Mar 15 2010 Oden Eriksson <oeriksson@mandriva.com> 2008-3mdv2010.1
+ Revision: 520138
- rebuilt for 2010.1

* Wed Sep 02 2009 Christophe Fergeau <cfergeau@mandriva.com> 2008-2mdv2010.0
+ Revision: 425501
- rebuild

* Mon Dec 29 2008 Emmanuel Andry <eandry@mandriva.org> 2008-1mdv2009.1
+ Revision: 321225
- New version 2008
- fix old X11 path in configure options
- fix license

* Fri Dec 21 2007 Olivier Blin <oblin@mandriva.com> 2002-13mdv2009.0
+ Revision: 136535
- restore BuildRoot

* Mon Dec 17 2007 Thierry Vignaud <tv@mandriva.org> 2002-13mdv2008.1
+ Revision: 128338
- kill re-definition of %%buildroot on Pixel's request


* Thu Mar 01 2007 Giuseppe Ghibò <ghibo@mandriva.com> 2002-13mdv2007.0
+ Revision: 130671
- Use %%mkrel.
- Import latex2html

* Sat Mar 19 2005 Giuseppe Ghibò <ghibo@mandrakesoft.com> 2002-12mdk
- Added Patch7, for html.sty from latex2html author.

* Sat Mar 12 2005 Giuseppe Ghibò <ghibo@mandrakesoft.com> 2002-11mdk
- latex2html-2002-2-1 (25-Oct-2004).
- removed \\address{...} usage in documentation (Patch3).
- Let latex/pdflatex checking in html.sty more robust (Patch4).
- Added Patch5 because 'gs -h' outputs to stderr.

* Sat Aug 28 2004 Giuseppe Ghibò <ghibo@mandrakesoft.com> 2002-10mdk
- Rebuilt.

